import static jcuda.driver.JCudaDriver.cuCtxCreate;
import static jcuda.driver.JCudaDriver.cuCtxDestroy;
import static jcuda.driver.JCudaDriver.cuDeviceGet;
import static jcuda.driver.JCudaDriver.cuInit;
import static jcuda.driver.JCudaDriver.cuMemAlloc;
import static jcuda.driver.JCudaDriver.cuMemFree;

import java.io.IOException;

import jcuda.Sizeof;
import jcuda.driver.CUcontext;
import jcuda.driver.CUdevice;
import jcuda.driver.CUdeviceptr;
import jcuda.driver.JCudaDriver;

public class JCudaMinTest
{
    public static void main(String args[]) throws IOException
    {
    	if (JCudaAvailabilityTest.isCudaAvailable())
    	{
    		runTest();
    	}
    	else
    	{
    		System.out.println("CUDA is not available");
    	}
    }

	private static void runTest() 
	{
        // Enable exceptions and omit all subsequent error checks
        JCudaDriver.setExceptionsEnabled(true);

        // Initialize the driver and create a context for the first device.
        cuInit(0);
        CUdevice device = new CUdevice();
        cuDeviceGet(device, 0);
        CUcontext context = new CUcontext();
        cuCtxCreate(context, 0, device);

        // Allocate some memory
        CUdeviceptr p = new CUdeviceptr();
        cuMemAlloc(p, 10 * Sizeof.FLOAT);
        
        System.out.println("Allocated "+p);
        
        cuMemFree(p);
        cuCtxDestroy(context);
        
        System.out.println("Done");
	}

}


class JCudaAvailabilityTest
{
	public static boolean isCudaAvailable()
	{
		try
		{
			cuInit(0);
			return true;
		}
		catch (Throwable t)
		{
			t.printStackTrace();
			return false;
		}
	}
}